@@ -547,7 +547,13 @@ def test_default_dtypes(
 ):
     if use_bqstorage_api not in use_bqstorage_apis:
         pytest.skip(f"use_bqstorage_api={use_bqstorage_api} not supported.")
-    result = read_gbq(query, use_bqstorage_api=use_bqstorage_api)
+    # the parameter useQueryCache=False is used in the following function call
+    # to avoid a failing test due to cached data that may be out of order.
+    result = read_gbq(
+        query,
+        use_bqstorage_api=use_bqstorage_api,
+        configuration={"query": {"useQueryCache": False}},
+    )
     pandas.testing.assert_frame_equal(result, expected)
 
 
